@@ -6,93 +6,45 @@
     <message>
         <location filename="../../../config/addplugindialog.ui" line="14"/>
         <source>Add Plugins</source>
-        <translation type="unfinished"></translation>
+        <translation>Tilføj plugins</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="22"/>
         <source>Search:</source>
-        <translation type="unfinished"></translation>
+        <translation>Søg:</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="98"/>
         <source>Add Widget</source>
-        <translation type="unfinished"></translation>
+        <translation>Tilføj widget</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.ui" line="105"/>
         <source>Close</source>
-        <translation type="unfinished"></translation>
+        <translation>Luk</translation>
     </message>
     <message>
         <location filename="../../../config/addplugindialog.cpp" line="115"/>
         <source>(only one instance can run at a time)</source>
-        <translation type="unfinished"></translation>
+        <translation>(kan kun køre én instans af gangen)</translation>
     </message>
 </context>
 <context>
     <name>ConfigPanelDialog</name>
-    <message>
-        <source>Configure panel</source>
-        <translation type="vanished">Indstil panel</translation>
-    </message>
-    <message>
-        <source>Panel size</source>
-        <translation type="vanished">Panelstørrelse</translation>
-    </message>
-    <message>
-        <source>Size:</source>
-        <translation type="vanished">Størrelse:</translation>
-    </message>
-    <message>
-        <source>px</source>
-        <translation type="vanished">pkt</translation>
-    </message>
-    <message>
-        <source>Use theme size</source>
-        <translation type="vanished">Brug tema-størrelse</translation>
-    </message>
-    <message>
-        <source>Panel lenght &amp; position</source>
-        <translation type="vanished">Panel længde &amp; position</translation>
-    </message>
-    <message>
-        <source>Length:</source>
-        <translation type="vanished">Længde:</translation>
-    </message>
-    <message>
-        <source>Alignment:</source>
-        <translation type="vanished">Placering:</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation type="vanished">Venstre</translation>
-    </message>
-    <message>
-        <source>Center</source>
-        <translation type="vanished">Midtpå</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation type="vanished">Højre</translation>
-    </message>
-    <message>
-        <source>%</source>
-        <translation type="vanished">%</translation>
-    </message>
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="31"/>
         <source>Configure Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurationspanel</translation>
     </message>
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="38"/>
         <source>Panel</source>
-        <translation type="unfinished">Panel</translation>
+        <translation>Panel</translation>
     </message>
     <message>
         <location filename="../../../config/configpaneldialog.cpp" line="42"/>
         <source>Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>Widgets</translation>
     </message>
 </context>
 <context>
@@ -100,204 +52,204 @@
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="20"/>
         <source>Configure panel</source>
-        <translation type="unfinished">Indstil panel</translation>
+        <translation>Konfigurér panel</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="44"/>
         <source>Size</source>
-        <translation type="unfinished"></translation>
+        <translation>Størrelse</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="81"/>
         <source>Size:</source>
-        <translation type="unfinished">Størrelse:</translation>
+        <translation>Størrelse:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="109"/>
         <location filename="../../../config/configpanelwidget.ui" line="153"/>
         <source> px</source>
-        <translation type="unfinished"></translation>
+        <translation> px</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="166"/>
         <source>Icon size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Ikonstørrelse:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="88"/>
         <source>Length:</source>
-        <translation type="unfinished">Længde:</translation>
+        <translation>Længde:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="68"/>
         <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;Negative pixel-værdier sætter panelets længe til så mange pixel mindre end den tilgængelige skærmplads.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;F.eks. &quot;Længde&quot; sæt til -100px, skærmstørrelse er 1000px, så vil den rigtige panellængde blive 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="96"/>
         <source>%</source>
-        <translation type="unfinished">%</translation>
+        <translation>%</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="101"/>
         <source>px</source>
-        <translation type="unfinished">pkt</translation>
+        <translation>px</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="173"/>
         <source>Rows count:</source>
-        <translation type="unfinished"></translation>
+        <translation>Række antal:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="202"/>
         <source>Alignment &amp;&amp; position</source>
-        <translation type="unfinished"></translation>
+        <translation>Justering og placering</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="224"/>
         <location filename="../../../config/configpanelwidget.ui" line="250"/>
         <source>Zero means no animation</source>
-        <translation type="unfinished"></translation>
+        <translation>Nul betyder ingen animation</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="227"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="253"/>
         <source>Animation duration:</source>
-        <translation type="unfinished"></translation>
+        <translation>Animationens varighed:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="284"/>
         <location filename="../../../config/configpanelwidget.cpp" line="195"/>
         <source>Left</source>
-        <translation type="unfinished">Venstre</translation>
+        <translation>Venstre</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="289"/>
         <location filename="../../../config/configpanelwidget.cpp" line="196"/>
         <location filename="../../../config/configpanelwidget.cpp" line="202"/>
         <source>Center</source>
-        <translation type="unfinished">Midtpå</translation>
+        <translation>Centereret</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="294"/>
         <location filename="../../../config/configpanelwidget.cpp" line="197"/>
         <source>Right</source>
-        <translation type="unfinished">Højre</translation>
+        <translation>Højre</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="314"/>
         <source>Custom styling</source>
-        <translation type="unfinished"></translation>
+        <translation>Brugerdefineret udseende</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="335"/>
         <source>Font color:</source>
-        <translation type="unfinished"></translation>
+        <translation>Skriftfarve:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="375"/>
         <source>Background color:</source>
-        <translation type="unfinished"></translation>
+        <translation>Baggrundsfarve:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="414"/>
         <source>Background opacity:</source>
-        <translation type="unfinished"></translation>
+        <translation>Baggrundens opacity:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="446"/>
         <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;small&gt;Komposition kræves for panelet kan være gennemsigtigt.&lt;/small&gt;</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="474"/>
         <source>Background image:</source>
-        <translation type="unfinished"></translation>
+        <translation>Baggrundsbillede:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="260"/>
         <source>Alignment:</source>
-        <translation type="unfinished">Placering:</translation>
+        <translation>Justering:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="240"/>
         <source>Position:</source>
-        <translation type="unfinished"></translation>
+        <translation>Placering:</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.ui" line="214"/>
         <source>Auto-hide</source>
-        <translation type="unfinished"></translation>
+        <translation>Skjul automatisk</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="161"/>
         <source>Top of desktop</source>
-        <translation type="unfinished">Toppen af skrivebordet</translation>
+        <translation>Øverst på skrivebordet</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="162"/>
         <source>Left of desktop</source>
-        <translation type="unfinished">Venstre side af skrivebordet</translation>
+        <translation>Til venstre på skrivebordet</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="163"/>
         <source>Right of desktop</source>
-        <translation type="unfinished">Højre side af skrivebordet</translation>
+        <translation>Til højre på skrivebordet</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="164"/>
         <source>Bottom of desktop</source>
-        <translation type="unfinished">Bunden af skrivebordet</translation>
+        <translation>Nederst på skrivebordet</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="173"/>
         <source>Top of desktop %1</source>
-        <translation type="unfinished">Toppen af skrivebord %1</translation>
+        <translation>Øverst på skrivebord %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="174"/>
         <source>Left of desktop %1</source>
-        <translation type="unfinished">Venstre side af skrivebord %1</translation>
+        <translation>Til venstre på skrivebord %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="175"/>
         <source>Right of desktop %1</source>
-        <translation type="unfinished">Højre side af skrivebord %1</translation>
+        <translation>Til højre på skrivebord %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="176"/>
         <source>Bottom of desktop %1</source>
-        <translation type="unfinished">Bunden af skrivebord %1</translation>
+        <translation>Nederst på skrivebord %1</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="201"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>Øverst</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="203"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>Nederst</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="360"/>
         <location filename="../../../config/configpanelwidget.cpp" line="376"/>
         <source>Pick color</source>
-        <translation type="unfinished"></translation>
+        <translation>Vælg farve</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="394"/>
         <source>Images (*.png *.gif *.jpg)</source>
-        <translation type="unfinished"></translation>
+        <translation>Billeder (*.png *.gif *.jpg)</translation>
     </message>
     <message>
         <location filename="../../../config/configpanelwidget.cpp" line="394"/>
         <source>Pick image</source>
-        <translation type="unfinished"></translation>
+        <translation>Vælg billede</translation>
     </message>
 </context>
 <context>
@@ -305,17 +257,17 @@
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="14"/>
         <source>Configure Plugins</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurér plugins</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="84"/>
         <source>Note: changes made in this page cannot be reset.</source>
-        <translation type="unfinished"></translation>
+        <translation>Bemærk: ændringer foretaget på denne side kan ikke nulstilles.</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="112"/>
         <source>Move up</source>
-        <translation type="unfinished"></translation>
+        <translation>Flyt op</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="115"/>
@@ -324,27 +276,27 @@
         <location filename="../../../config/configpluginswidget.ui" line="164"/>
         <location filename="../../../config/configpluginswidget.ui" line="185"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="126"/>
         <source>Move down</source>
-        <translation type="unfinished"></translation>
+        <translation>Flyt ned</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="147"/>
         <source>Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Tilføj</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="161"/>
         <source>Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjern</translation>
     </message>
     <message>
         <location filename="../../../config/configpluginswidget.ui" line="182"/>
         <source>Configure</source>
-        <translation type="unfinished">Indstil</translation>
+        <translation>Konfigurér</translation>
     </message>
 </context>
 <context>
@@ -353,89 +305,40 @@
         <location filename="../../../lxqtpanel.cpp" line="1012"/>
         <location filename="../../../lxqtpanel.cpp" line="1036"/>
         <source>Panel</source>
-        <translation type="unfinished">Panel</translation>
+        <translation>Panel</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1039"/>
         <source>Configure Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurér panel</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1044"/>
         <source>Manage Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>Håndtér widgets</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1050"/>
         <source>Add New Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Tilføj nyt panel</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1062"/>
         <source>Lock This Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Lås dette panel</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1200"/>
         <source>Removing a panel can not be undone.
 Do you want to remove this panel?</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjernelse af et panel kan ikke fortrydes.
+Vil du fjerne dette panel?</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanel.cpp" line="1057"/>
         <location filename="../../../lxqtpanel.cpp" line="1199"/>
         <source>Remove Panel</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>LXQtPanelPluginPrivate</name>
-    <message>
-        <source>Configure</source>
-        <translation type="vanished">Indstil</translation>
-    </message>
-    <message>
-        <source>Move</source>
-        <translation type="vanished">Flyt</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="vanished">Slet</translation>
-    </message>
-</context>
-<context>
-    <name>LXQtPanelPrivate</name>
-    <message>
-        <source>Panel</source>
-        <translation type="vanished">Panel</translation>
-    </message>
-    <message>
-        <source>Plugins</source>
-        <translation type="vanished">Udvidelsesmoduler</translation>
-    </message>
-    <message>
-        <source>Add plugins ...</source>
-        <translation type="vanished">Tilføj udvidelsesmoduler ...</translation>
-    </message>
-    <message>
-        <source>Move plugin</source>
-        <translation type="vanished">Flyt udvidelsesmodul</translation>
-    </message>
-    <message>
-        <source>Configure plugin</source>
-        <translation type="vanished">Indstil udvidelsesmodul</translation>
-    </message>
-    <message>
-        <source>Delete plugin</source>
-        <translation type="vanished">Fjern udvidelsesmodul</translation>
-    </message>
-    <message>
-        <source>Show this panel at</source>
-        <translation type="vanished">Vis dette panel ved</translation>
-    </message>
-    <message>
-        <source>Configure panel</source>
-        <translation type="vanished">Indstil panel</translation>
+        <translation>Fjern panel</translation>
     </message>
 </context>
 <context>
@@ -443,52 +346,17 @@ Do you want to remove this panel?</source>
     <message>
         <location filename="../../../plugin.cpp" line="385"/>
         <source>Configure &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurér &quot;%1&quot;</translation>
     </message>
     <message>
         <location filename="../../../plugin.cpp" line="390"/>
         <source>Move &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Flyt &quot;%1&quot;</translation>
     </message>
     <message>
         <location filename="../../../plugin.cpp" line="398"/>
         <source>Remove &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>PositionAction</name>
-    <message>
-        <source>Top of desktop</source>
-        <translation type="vanished">Toppen af skrivebordet</translation>
-    </message>
-    <message>
-        <source>Bottom of desktop</source>
-        <translation type="vanished">Bunden af skrivebordet</translation>
-    </message>
-    <message>
-        <source>Left of desktop</source>
-        <translation type="vanished">Venstre side af skrivebordet</translation>
-    </message>
-    <message>
-        <source>Right of desktop</source>
-        <translation type="vanished">Højre side af skrivebordet</translation>
-    </message>
-    <message>
-        <source>Top of desktop %1</source>
-        <translation type="vanished">Toppen af skrivebord %1</translation>
-    </message>
-    <message>
-        <source>Bottom of desktop %1</source>
-        <translation type="vanished">Bunden af skrivebord %1</translation>
-    </message>
-    <message>
-        <source>Left of desktop %1</source>
-        <translation type="vanished">Venstre side af skrivebord %1</translation>
-    </message>
-    <message>
-        <source>Right of desktop %1</source>
-        <translation type="vanished">Højre side af skrivebord %1</translation>
+        <translation>Fjern &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -496,12 +364,12 @@ Do you want to remove this panel?</source>
     <message>
         <location filename="../../../lxqtpanelapplication.cpp" line="91"/>
         <source>Use alternate configuration file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Brug alternativ konfigurationsfil.</translation>
     </message>
     <message>
         <location filename="../../../lxqtpanelapplication.cpp" line="92"/>
         <source>Configuration file</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfigurationsfil</translation>
     </message>
 </context>
 </TS>
